# aioairzone-cloud
[![Latest Version][mdversion-button]][md-pypi]
[![Python Versions][pyversion-button]][md-pypi]
[![License: Apache 2.0][apache-button]](LICENSE)

[apache-button]: https://img.shields.io/badge/License-Apache%202.0-blue.svg
[md-pypi]: https://pypi.org/project/aioairzone-cloud
[mdversion-button]: https://img.shields.io/pypi/v/aioairzone-cloud.svg
[pyversion-button]: https://img.shields.io/pypi/pyversions/aioairzone-cloud.svg

Python library to control Airzone Cloud devices.

## Requirements
- Python >= 3.10

## Install
```bash
pip install aioairzone-cloud
```

## Install from Source
Run the following command inside this folder
```bash
pip install --upgrade .
```

## Examples
Examples can be found in the `examples` folder
